@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # This file is part of the jetson_stats package (https://github.com/rbonghi/jetson_stats or http://rnext.it).
-# Copyright (c) 2019 Raffaello Bonghi.
+# Copyright (c) 2019-2023 Raffaello Bonghi.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -17,17 +17,14 @@
 
 # flake8: noqa
 
-from .jtop import jtop, import_jetson_variables
-# Import extra controllers
-from .core import Tegrastats
-from .core import Fan
-from .core import NVPmodel
-from .core import JetsonClocks
-# Import os variable importer
-from .core import StatusObserver
+from .core import JtopException
+from .jtop import jtop
 
-__author__ = "Raffaello Bonghi <raffaello@rnext.it>"
+__author__ = "Raffaello Bonghi"
+__email__ = "raffaello@rnext.it"
+__cr__ = "(c) 2023, RB"
+__copyright__ = "(c) 2023, Raffaello Bonghi"
 # Version package
 # https://packaging.python.org/guides/distributing-packages-using-setuptools/#choosing-a-versioning-scheme
-__version__ = "2.0.0"
+__version__ = "4.1.1"
 # EOF
